@@ -23,6 +23,8 @@ rm -f CMakeCache.txt
 
 cmake \
 ${RPATH} \
+-D CMAKE_POLICY_VERSION_MINIMUM=3.5 \
+-D CMAKE_POSITION_INDEPENDENT_CODE:BOOL=ON \
 -D BUILD_SHARED_LIBS:BOOL=${SHARED} \
 -D CMAKE_PREFIX_PATH:PATH=${INSTALL_PATH}/lib \
 -D CMAKE_INSTALL_PREFIX:PATH=${INSTALL_PATH} \
