@@ -57,11 +57,13 @@ rm -f config.cache
 
 cmake .. -DCMAKE_C_COMPILER:FILEPATH=${CC} \
          -DBUILD_SHARED_LIBS:BOOL=${SHARED} \
+         -DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=ON \
          -DBUILD_TESTING:BOOL=OFF \
          -DCMAKE_INSTALL_PREFIX=${INSTALL_PATH} \
 	 -DCMAKE_BUILD_TYPE=${BUILD_TYPE} \
 	 -DDEFAULT_API_VERSION=V18 \
 	 -DH5_DEFAULT_PLUGINDIR:PATH=${INSTALL_PATH}/lib/hdf5/lib/plugin \
+	 -DHDF5_ENABLE_NONSTANDARD_FEATURE_FLOAT16=OFF \
 	 -DHDF5_ENABLE_PARALLEL:BOOL=${MPI} \
 	 -DHDF5_ENABLE_Z_LIB_SUPPORT:BOOL=ON \
 	 -DHDF5_BUILD_CPP_LIB:BOOL=${H5CPP} \
