@@ -1,4 +1,4 @@
-// Copyright(C) 1999-2020, 2022, 2023 National Technology & Engineering Solutions
+// Copyright(C) 1999-2020, 2022, 2023, 2025 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
@@ -6,9 +6,8 @@
 #pragma once
 
 #include "exo_entity.h"
-#include <iostream>
 
-template <typename INT> class ExoII_Read;
+template <typename INT> class Exo_Read;
 
 template <typename INT> class Edge_Block : public Exo_Entity
 {
@@ -34,5 +33,5 @@ private:
   std::string elmt_type{};
   int         num_edges_per_elmt{-1};
 
-  friend class ExoII_Read<INT>;
+  friend class Exo_Read<INT>;
 };
