@@ -1,5 +1,5 @@
 /*
- * Copyright(C) 1999-2020 National Technology & Engineering Solutions
+ * Copyright(C) 1999-2020, 2024 National Technology & Engineering Solutions
  * of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
  * NTESS, the U.S. Government retains certain rights in this software.
  *
@@ -10,7 +10,8 @@
 #include "exodusII_int.h" // for EX_FATAL, EX_NOERR
 
 /**
- * \ingroup Utilities Given a file or group 'parent' id, return the
+ * \ingroup Utilities
+ * Given a file or group 'parent' id, return the
  * number of child groups and the ids of the child groups below the
  * parent.  If num_groups is NULL, do not return count; if group_ids
  * is NULL, do not return ids.
@@ -28,7 +29,7 @@ int ex_get_group_ids(int parent_id, int *num_groups, int *group_ids)
   }
 
   status = nc_inq_grps(parent_id, num_groups, group_ids);
-  if (status != NC_NOERR) {
+  if (status != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Failed to get child group ids in file id %d",
              parent_id);
     ex_err_fn(parent_id, __func__, errmsg, status);
