@@ -1,5 +1,5 @@
 /*
- * Copyright(C) 1999-2024 National Technology & Engineering Solutions
+ * Copyright(C) 1999-2025 National Technology & Engineering Solutions
  * of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
  * NTESS, the U.S. Government retains certain rights in this software.
  *
@@ -38,7 +38,7 @@ static int  exi_define_vars(int exoid, ex_entity_type obj_type, const char *enti
 #define EX_GET_IDS_STATUS(TNAME, NUMVAR, DNAME, DID, DVAL, VIDS, EIDS, VSTAT, VSTATVAL)            \
   if (NUMVAR > 0) {                                                                                \
     status = exi_get_dimension(exoid, DNAME, TNAME "s", &DVAL, &DID, __func__);                    \
-    if (status != NC_NOERR)                                                                        \
+    if (status != EX_NOERR)                                                                        \
       goto error_ret;                                                                              \
                                                                                                    \
     /* get element block IDs */                                                                    \
@@ -109,18 +109,18 @@ int ex_put_all_var_param_ext(int exoid, const ex_var_params *vp)
 
   /* inquire previously defined dimensions  */
 
-  if ((status = nc_inq_dimid(exoid, DIM_TIME, &time_dim)) != NC_NOERR) {
+  if ((status = nc_inq_dimid(exoid, DIM_TIME, &time_dim)) != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate time dimension in file id %d", exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
     goto error_ret;
   }
 
-  if (nc_inq_dimid(exoid, DIM_NUM_NODES, &num_nod_dim) != NC_NOERR) {
+  if (nc_inq_dimid(exoid, DIM_NUM_NODES, &num_nod_dim) != EX_NOERR) {
     num_nod_dim = -1; /* There is probably no nodes on this file */
   }
 
   /* Check this now so we can use it later without checking for errors */
-  if ((status = nc_inq_dimid(exoid, DIM_STR_NAME, &temp)) != NC_NOERR) {
+  if ((status = nc_inq_dimid(exoid, DIM_STR_NAME, &temp)) != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get string length in file id %d", exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
     goto error_ret;
@@ -144,7 +144,7 @@ int ex_put_all_var_param_ext(int exoid, const ex_var_params *vp)
                     EX_ELEM_SET, VAR_ELS_STAT, elset_stat);
 
   /* put file into define mode  */
-  if ((status = exi_redef(exoid, __func__)) != NC_NOERR) {
+  if ((status = exi_redef(exoid, __func__)) != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to put file id %d into define mode", exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
     goto error_ret;
@@ -153,14 +153,14 @@ int ex_put_all_var_param_ext(int exoid, const ex_var_params *vp)
 
   /* define dimensions and variables */
   if (vp->num_glob > 0) {
-    if (define_dimension(exoid, DIM_NUM_GLO_VAR, vp->num_glob, "global", &dimid) != NC_NOERR) {
+    if (define_dimension(exoid, DIM_NUM_GLO_VAR, vp->num_glob, "global", &dimid) != EX_NOERR) {
       goto error_ret;
     }
 
     dims[0] = time_dim;
     dims[1] = dimid;
     if ((status = nc_def_var(exoid, VAR_GLO_VAR, nc_flt_code(exoid), 2, dims, &varid)) !=
-        NC_NOERR) {
+        EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define global variables in file id %d",
                exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -169,13 +169,13 @@ int ex_put_all_var_param_ext(int exoid, const ex_var_params *vp)
     exi_compress_variable(exoid, varid, 2);
 
     /* Now define global variable name variable */
-    if (define_variable_name_variable(exoid, VAR_NAME_GLO_VAR, dimid, "global") != NC_NOERR) {
+    if (define_variable_name_variable(exoid, VAR_NAME_GLO_VAR, dimid, "global") != EX_NOERR) {
       goto error_ret;
     }
   }
 
   if (vp->num_node > 0) {
-    if (define_dimension(exoid, DIM_NUM_NOD_VAR, vp->num_node, "nodal", &dimid) != NC_NOERR) {
+    if (define_dimension(exoid, DIM_NUM_NOD_VAR, vp->num_node, "nodal", &dimid) != EX_NOERR) {
       goto error_ret;
     }
 
@@ -184,7 +184,7 @@ int ex_put_all_var_param_ext(int exoid, const ex_var_params *vp)
         dims[0] = time_dim;
         dims[1] = num_nod_dim;
         if ((status = nc_def_var(exoid, VAR_NOD_VAR_NEW(i), nc_flt_code(exoid), 2, dims, &varid)) !=
-            NC_NOERR) {
+            EX_NOERR) {
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to define nodal variable %d in file id %d", i, exoid);
           ex_err_fn(exoid, __func__, errmsg, status);
@@ -195,7 +195,7 @@ int ex_put_all_var_param_ext(int exoid, const ex_var_params *vp)
     }
 
     /* Now define nodal variable name variable */
-    if (define_variable_name_variable(exoid, VAR_NAME_NOD_VAR, dimid, "nodal") != NC_NOERR) {
+    if (define_variable_name_variable(exoid, VAR_NAME_NOD_VAR, dimid, "nodal") != EX_NOERR) {
       goto error_ret;
     }
   }
@@ -253,57 +253,57 @@ int ex_put_all_var_param_ext(int exoid, const ex_var_params *vp)
   /* leave define mode  */
 
   in_define = 0;
-  if ((status = exi_leavedef(exoid, __func__)) != NC_NOERR) {
+  if ((status = exi_leavedef(exoid, __func__)) != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to exit define mode");
     ex_err_fn(exoid, __func__, errmsg, status);
     goto error_ret;
   }
 
   /* write out the variable truth tables */
-  if (vp->num_edge > 0) {
-    if (put_truth_table(exoid, edblk_varid, vp->edge_var_tab, "edge") != NC_NOERR) {
+  if (vp->num_edge > 0 && vp->edge_var_tab != NULL) {
+    if (put_truth_table(exoid, edblk_varid, vp->edge_var_tab, "edge") != EX_NOERR) {
       goto error_ret;
     }
   }
 
-  if (vp->num_face > 0) {
-    if (put_truth_table(exoid, fablk_varid, vp->face_var_tab, "face") != NC_NOERR) {
+  if (vp->num_face > 0 && vp->face_var_tab != NULL) {
+    if (put_truth_table(exoid, fablk_varid, vp->face_var_tab, "face") != EX_NOERR) {
       goto error_ret;
     }
   }
 
-  if (vp->num_elem > 0) {
-    if (put_truth_table(exoid, eblk_varid, vp->elem_var_tab, "element") != NC_NOERR) {
+  if (vp->num_elem > 0 && vp->elem_var_tab != NULL) {
+    if (put_truth_table(exoid, eblk_varid, vp->elem_var_tab, "element") != EX_NOERR) {
       goto error_ret;
     }
   }
 
-  if (vp->num_nset > 0) {
-    if (put_truth_table(exoid, nset_varid, vp->nset_var_tab, "nodeset") != NC_NOERR) {
+  if (vp->num_nset > 0 && vp->nset_var_tab != NULL) {
+    if (put_truth_table(exoid, nset_varid, vp->nset_var_tab, "nodeset") != EX_NOERR) {
       goto error_ret;
     }
   }
 
-  if (vp->num_eset > 0) {
-    if (put_truth_table(exoid, eset_varid, vp->eset_var_tab, "edgeset") != NC_NOERR) {
+  if (vp->num_eset > 0 && vp->eset_var_tab != NULL) {
+    if (put_truth_table(exoid, eset_varid, vp->eset_var_tab, "edgeset") != EX_NOERR) {
       goto error_ret;
     }
   }
 
-  if (vp->num_fset > 0) {
-    if (put_truth_table(exoid, fset_varid, vp->fset_var_tab, "faceset") != NC_NOERR) {
+  if (vp->num_fset > 0 && vp->fset_var_tab != NULL) {
+    if (put_truth_table(exoid, fset_varid, vp->fset_var_tab, "faceset") != EX_NOERR) {
       goto error_ret;
     }
   }
 
-  if (vp->num_sset > 0) {
-    if (put_truth_table(exoid, sset_varid, vp->sset_var_tab, "sideset") != NC_NOERR) {
+  if (vp->num_sset > 0 && vp->sset_var_tab != NULL) {
+    if (put_truth_table(exoid, sset_varid, vp->sset_var_tab, "sideset") != EX_NOERR) {
       goto error_ret;
     }
   }
 
-  if (vp->num_elset > 0) {
-    if (put_truth_table(exoid, elset_varid, vp->elset_var_tab, "elemset") != NC_NOERR) {
+  if (vp->num_elset > 0 && vp->elset_var_tab != NULL) {
+    if (put_truth_table(exoid, elset_varid, vp->elset_var_tab, "elemset") != EX_NOERR) {
       goto error_ret;
     }
   }
@@ -340,7 +340,7 @@ static int define_dimension(int exoid, const char *DIMENSION, int count, const c
                             int *dimid)
 {
   int status;
-  if ((status = nc_def_dim(exoid, DIMENSION, count, dimid)) != NC_NOERR) {
+  if ((status = nc_def_dim(exoid, DIMENSION, count, dimid)) != EX_NOERR) {
     if (status == NC_ENAMEINUSE) {
       char errmsg[MAX_ERR_LENGTH];
       snprintf(errmsg, MAX_ERR_LENGTH,
@@ -356,7 +356,7 @@ static int define_dimension(int exoid, const char *DIMENSION, int count, const c
       ex_err_fn(exoid, __func__, errmsg, status);
     }
   }
-  return (status);
+  return status;
 }
 
 static int define_variable_name_variable(int exoid, const char *VARIABLE, int dimension,
@@ -368,7 +368,7 @@ static int define_variable_name_variable(int exoid, const char *VARIABLE, int di
 
   int variable;
   int status;
-  if ((status = nc_def_var(exoid, VARIABLE, NC_CHAR, 2, dims, &variable)) != NC_NOERR) {
+  if ((status = nc_def_var(exoid, VARIABLE, NC_CHAR, 2, dims, &variable)) != EX_NOERR) {
     if (status == NC_ENAMEINUSE) {
       char errmsg[MAX_ERR_LENGTH];
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: %s variable names are already defined in file id %d",
@@ -387,7 +387,7 @@ static int define_variable_name_variable(int exoid, const char *VARIABLE, int di
   int fill = NC_FILL_CHAR;
   nc_def_var_fill(exoid, variable, 0, &fill);
 #endif
-  return (status);
+  return status;
 }
 
 static int *get_status_array(int exoid, int var_count, const char *VARIABLE, const char *label)
@@ -399,23 +399,23 @@ static int *get_status_array(int exoid, int var_count, const char *VARIABLE, con
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to allocate memory for %s status array for file id %d", label, exoid);
     ex_err_fn(exoid, __func__, errmsg, EX_MEMFAIL);
-    return (NULL);
+    return NULL;
   }
 
   /* get variable id of status array */
   int varid;
-  if ((nc_inq_varid(exoid, VARIABLE, &varid)) == NC_NOERR) {
+  if ((nc_inq_varid(exoid, VARIABLE, &varid)) == EX_NOERR) {
     /* if status array exists (V 2.01+), use it, otherwise assume
        object exists to be backward compatible */
 
     int status;
-    if ((status = nc_get_var_int(exoid, varid, stat_vals)) != NC_NOERR) {
+    if ((status = nc_get_var_int(exoid, varid, stat_vals)) != EX_NOERR) {
       free(stat_vals);
       char errmsg[MAX_ERR_LENGTH];
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s status array from file id %d",
                label, exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
-      return (NULL);
+      return NULL;
     }
   }
   else {
@@ -431,7 +431,7 @@ static int put_truth_table(int exoid, int varid, int *table, const char *label)
 {
   int iresult = nc_put_var_int(exoid, varid, table);
 
-  if (iresult != NC_NOERR) {
+  if (iresult != EX_NOERR) {
     char errmsg[MAX_ERR_LENGTH];
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s variable truth table in file id %d",
              label, exoid);
@@ -447,7 +447,7 @@ static int define_truth_table(ex_entity_type obj_type, int exoid, int num_ent, i
   int varid;
   int status;
 
-  if ((status = nc_inq_dimid(exoid, DIM_TIME, &time_dim)) != NC_NOERR) {
+  if ((status = nc_inq_dimid(exoid, DIM_TIME, &time_dim)) != EX_NOERR) {
     char errmsg[MAX_ERR_LENGTH];
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate time dimension in file id %d", exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
@@ -483,13 +483,13 @@ static int define_truth_table(ex_entity_type obj_type, int exoid, int num_ent, i
           /* Determine number of entities in entity */
           /* Need way to make this more generic... */
           status = nc_inq_dimid(exoid, exi_dim_num_entries_in_object(obj_type, i + 1), &dims[1]);
-          if (status != NC_NOERR) {
+          if (status != EX_NOERR) {
             char errmsg[MAX_ERR_LENGTH];
             snprintf(errmsg, MAX_ERR_LENGTH,
                      "ERROR: failed to locate number of entities in %s %" PRId64 " in file id %d",
                      label, id, exoid);
             ex_err_fn(exoid, __func__, errmsg, status);
-            return (status);
+            return status;
           }
 
           /* define netCDF variable to store variable values;
@@ -499,14 +499,14 @@ static int define_truth_table(ex_entity_type obj_type, int exoid, int num_ent, i
            */
           status = nc_def_var(exoid, exi_name_var_of_object(obj_type, j, i + 1), nc_flt_code(exoid),
                               2, dims, &varid);
-          if (status != NC_NOERR) {
+          if (status != EX_NOERR) {
             if (status != NC_ENAMEINUSE) {
               char errmsg[MAX_ERR_LENGTH];
               snprintf(errmsg, MAX_ERR_LENGTH,
                        "ERROR: failed to define %s variable for %s %" PRId64 " in file id %d",
                        label, label, id, exoid);
               ex_err_fn(exoid, __func__, errmsg, status);
-              return (status);
+              return status;
             }
           }
           exi_compress_variable(exoid, varid, 2);
@@ -515,7 +515,7 @@ static int define_truth_table(ex_entity_type obj_type, int exoid, int num_ent, i
       k++; /* increment truth table pointer */
     } /* for j */
   } /* for i */
-  return NC_NOERR;
+  return EX_NOERR;
 }
 
 static int exi_define_vars(int exoid, ex_entity_type obj_type, const char *entity_name,
@@ -526,38 +526,40 @@ static int exi_define_vars(int exoid, ex_entity_type obj_type, const char *entit
 {
   if (numvar > 0) {
     int status;
-    if ((status = define_dimension(exoid, DNAME, numvar, entity_name, &dimid2)) != NC_NOERR) {
+    if ((status = define_dimension(exoid, DNAME, numvar, entity_name, &dimid2)) != EX_NOERR) {
       return status;
     }
 
     /* Now define entity_name variable name variable */
-    if ((status = define_variable_name_variable(exoid, VNOV, dimid2, entity_name)) != NC_NOERR) {
+    if ((status = define_variable_name_variable(exoid, VNOV, dimid2, entity_name)) != EX_NOERR) {
       return status;
     }
 
-    if ((status = define_truth_table(obj_type, exoid, DVAL, numvar, truth_table, *status_var,
-                                     *entity_ids, entity_blk_name)) != NC_NOERR) {
-      return status;
-    }
+    if (truth_table != NULL) {
+      if ((status = define_truth_table(obj_type, exoid, DVAL, numvar, truth_table, *status_var,
+                                       *entity_ids, entity_blk_name)) != EX_NOERR) {
+        return status;
+      }
 
+      /* create a variable array in which to store the entity_name variable truth
+       * table
+       */
+
+      int dims[] = {dimid1, dimid2};
+      if ((status = nc_def_var(exoid, VTV, NC_INT, 2, dims, truth_table_var)) != EX_NOERR) {
+        char errmsg[MAX_ERR_LENGTH];
+        snprintf(errmsg, MAX_ERR_LENGTH,
+                 "ERROR: failed to define %s variable truth table in file id %d", entity_name,
+                 exoid);
+        ex_err_fn(exoid, __func__, errmsg, status);
+        return status;
+      }
+      exi_set_compact_storage(exoid, *truth_table_var);
+    }
     free(*status_var);
     *status_var = NULL;
     free(*entity_ids);
     *entity_ids = NULL;
-
-    /* create a variable array in which to store the entity_name variable truth
-     * table
-     */
-
-    int dims[] = {dimid1, dimid2};
-    if ((status = nc_def_var(exoid, VTV, NC_INT, 2, dims, truth_table_var)) != NC_NOERR) {
-      char errmsg[MAX_ERR_LENGTH];
-      snprintf(errmsg, MAX_ERR_LENGTH,
-               "ERROR: failed to define %s variable truth table in file id %d", entity_name, exoid);
-      ex_err_fn(exoid, __func__, errmsg, status);
-      return status;
-    }
-    exi_set_compact_storage(exoid, *truth_table_var);
   }
-  return NC_NOERR;
+  return EX_NOERR;
 }
