@@ -1,5 +1,5 @@
 /*
- * Copyright(C) 1999-2023 National Technology & Engineering Solutions
+ * Copyright(C) 1999-2024 National Technology & Engineering Solutions
  * of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
  * NTESS, the U.S. Government retains certain rights in this software.
  *
@@ -55,7 +55,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
   const char *dnfpe       = NULL;
 
   if (block_count == 0) {
-    return (EX_NOERR);
+    return EX_NOERR;
   }
 
   EX_FUNC_ENTER();
@@ -113,7 +113,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       EX_FUNC_LEAVE(EX_FATAL);
     }
     if ((status = exi_get_dimension(exoid, dnumblk, ex_name_of_object(last_type), &num_blk, &dimid,
-                                    __func__)) != NC_NOERR) {
+                                    __func__)) != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: No %ss defined in file id %d",
                ex_name_of_object(last_type), exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -163,7 +163,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
 
     /* first check if any blocks of that type are specified */
     if ((status = exi_get_dimension(exoid, dnumblk, ex_name_of_object(blocks[i].type), &num_blk,
-                                    &dimid, __func__)) != NC_NOERR) {
+                                    &dimid, __func__)) != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: No %ss defined in file id %d",
                ex_name_of_object(blocks[i].type), exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -178,7 +178,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
        the database to determine the position
     */
 
-    if ((status = nc_inq_varid(exoid, vblkids, &varid)) != NC_NOERR) {
+    if ((status = nc_inq_varid(exoid, vblkids, &varid)) != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate %s ids in file id %d",
                ex_name_of_object(blocks[i].type), exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -217,7 +217,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     /* write out block id to previously defined id array variable*/
     status = nc_put_var1_longlong(exoid, varid, start, (long long *)&blocks[i].id);
 
-    if (status != NC_NOERR) {
+    if (status != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s id to file id %d",
                ex_name_of_object(blocks[i].type), exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -234,7 +234,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       blk_stat = 1; /* change element block status to TRUE */
     }
 
-    if ((status = nc_inq_varid(exoid, vblksta, &varid)) != NC_NOERR) {
+    if ((status = nc_inq_varid(exoid, vblksta, &varid)) != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate %s status in file id %d",
                ex_name_of_object(blocks[i].type), exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -242,7 +242,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       EX_FUNC_LEAVE(EX_FATAL);
     }
 
-    if ((status = nc_put_var1_int(exoid, varid, start, &blk_stat)) != NC_NOERR) {
+    if ((status = nc_put_var1_int(exoid, varid, start, &blk_stat)) != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to store %s id %" PRId64 " status to file id %d",
                ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -253,7 +253,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
   }
 
   /* put netcdf file into define mode  */
-  if ((status = exi_redef(exoid, __func__)) != NC_NOERR) {
+  if ((status = exi_redef(exoid, __func__)) != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to place file id %d into define mode", exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
     free(blocks_to_define);
@@ -310,7 +310,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     }
 
     /* define some dimensions and variables*/
-    if ((status = nc_def_dim(exoid, dneblk, blocks[i].num_entry, &numblkdim)) != NC_NOERR) {
+    if ((status = nc_def_dim(exoid, dneblk, blocks[i].num_entry, &numblkdim)) != EX_NOERR) {
       if (status == NC_ENAMEINUSE) { /* duplicate entry */
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: %s %" PRId64 " already defined in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -328,7 +328,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     if (dnnpe && blocks[i].num_nodes_per_entry > 0) {
       /* A nfaced block would not have any nodes defined... */
       if ((status = nc_def_dim(exoid, dnnpe, blocks[i].num_nodes_per_entry, &nnodperentdim)) !=
-          NC_NOERR) {
+          EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of nodes/entity for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -339,7 +339,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
 
     if (dnepe && blocks[i].num_edges_per_entry > 0) {
       if ((status = nc_def_dim(exoid, dnepe, blocks[i].num_edges_per_entry, &nedgperentdim)) !=
-          NC_NOERR) {
+          EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of edges/entity for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -350,7 +350,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
 
     if (dnfpe && blocks[i].num_faces_per_entry > 0) {
       if ((status = nc_def_dim(exoid, dnfpe, blocks[i].num_faces_per_entry, &nfacperentdim)) !=
-          NC_NOERR) {
+          EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of faces/entity for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -362,7 +362,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     /* element attribute array */
     if (blocks[i].num_attribute > 0) {
 
-      if ((status = nc_def_dim(exoid, dnape, blocks[i].num_attribute, &numattrdim)) != NC_NOERR) {
+      if ((status = nc_def_dim(exoid, dnape, blocks[i].num_attribute, &numattrdim)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of attributes in %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -373,7 +373,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       dims[0] = numblkdim;
       dims[1] = numattrdim;
 
-      if ((status = nc_def_var(exoid, vblkatt, nc_flt_code(exoid), 2, dims, &varid)) != NC_NOERR) {
+      if ((status = nc_def_var(exoid, vblkatt, nc_flt_code(exoid), 2, dims, &varid)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR:  failed to define attributes for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -383,7 +383,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       exi_compress_variable(exoid, varid, 2);
 
       /* inquire previously defined dimensions  */
-      if ((status = nc_inq_dimid(exoid, DIM_STR_NAME, &strdim)) != NC_NOERR) {
+      if ((status = nc_inq_dimid(exoid, DIM_STR_NAME, &strdim)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get string length in file id %d", exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
         goto error_ret;
@@ -393,7 +393,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       dims[0] = numattrdim;
       dims[1] = strdim;
 
-      if ((status = nc_def_var(exoid, vattnam, NC_CHAR, 2, dims, &att_name_varid)) != NC_NOERR) {
+      if ((status = nc_def_var(exoid, vattnam, NC_CHAR, 2, dims, &att_name_varid)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define %s attribute name array in file id %d",
                  ex_name_of_object(blocks[i].type), exoid);
@@ -462,7 +462,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
         entity_type2 = "ELEM";
       }
 
-      if ((status = nc_def_var(exoid, vconn, conn_int_type, 1, dims, &connid)) != NC_NOERR) {
+      if ((status = nc_def_var(exoid, vconn, conn_int_type, 1, dims, &connid)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to create connectivity array for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -473,7 +473,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       /* element face-per-element or node-per-element count array */
       dims[0] = numblkdim;
 
-      if ((status = nc_def_var(exoid, vnpecnt, conn_int_type, 1, dims, &npeid)) != NC_NOERR) {
+      if ((status = nc_def_var(exoid, vnpecnt, conn_int_type, 1, dims, &npeid)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to create face- or node- per-entity "
                  "count array for %s %" PRId64 " in file id %d",
@@ -483,7 +483,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       }
 
       if ((status = nc_put_att_text(exoid, npeid, "entity_type1", strlen(entity_type1) + 1,
-                                    entity_type1)) != NC_NOERR) {
+                                    entity_type1)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to store entity type attribute text for %s %" PRId64
                  " in file id %d",
@@ -492,7 +492,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
         goto error_ret; /* exit define mode and return */
       }
       if ((status = nc_put_att_text(exoid, npeid, "entity_type2", strlen(entity_type2) + 1,
-                                    entity_type2)) != NC_NOERR) {
+                                    entity_type2)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to store entity type attribute text for %s %" PRId64
                  " in file id %d",
@@ -507,7 +507,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
         dims[0] = numblkdim;
         dims[1] = nnodperentdim;
 
-        if ((status = nc_def_var(exoid, vnodcon, conn_int_type, 2, dims, &connid)) != NC_NOERR) {
+        if ((status = nc_def_var(exoid, vnodcon, conn_int_type, 2, dims, &connid)) != EX_NOERR) {
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to create connectivity array for %s %" PRId64 " in file id %d",
                    ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
@@ -520,7 +520,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     /* store element type as attribute of connectivity variable */
     if (connid > 0) {
       if ((status = nc_put_att_text(exoid, connid, ATT_NAME_ELB, strlen(blocks[i].topology) + 1,
-                                    blocks[i].topology)) != NC_NOERR) {
+                                    blocks[i].topology)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s type name %s in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].topology, exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
@@ -533,7 +533,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
         dims[0] = numblkdim;
         dims[1] = nedgperentdim;
 
-        if ((status = nc_def_var(exoid, vedgcon, conn_int_type, 2, dims, &varid)) != NC_NOERR) {
+        if ((status = nc_def_var(exoid, vedgcon, conn_int_type, 2, dims, &varid)) != EX_NOERR) {
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to create edge connectivity array for %s %" PRId64
                    " in file id %d",
@@ -547,7 +547,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
         dims[0] = numblkdim;
         dims[1] = nfacperentdim;
 
-        if ((status = nc_def_var(exoid, vfaccon, conn_int_type, 2, dims, &varid)) != NC_NOERR) {
+        if ((status = nc_def_var(exoid, vfaccon, conn_int_type, 2, dims, &varid)) != EX_NOERR) {
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to create face connectivity array for %s %" PRId64
                    " in file id %d",
@@ -562,7 +562,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
   free(blocks_to_define);
 
   /* leave define mode  */
-  if ((status = exi_leavedef(exoid, __func__)) != NC_NOERR) {
+  if ((status = exi_leavedef(exoid, __func__)) != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to exit define mode");
     ex_err_fn(exoid, __func__, errmsg, status);
     EX_FUNC_LEAVE(EX_FATAL);
@@ -584,13 +584,12 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       */
       size_t count[2];
       char  *text = "";
-      size_t j;
 
       count[0] = 1;
       start[1] = 0;
       count[1] = strlen(text) + 1;
 
-      for (j = 0; j < blocks[i].num_attribute; j++) {
+      for (int64_t j = 0; j < blocks[i].num_attribute; j++) {
         start[0] = j;
         nc_put_vara_text(exoid, att_name_varid, start, count, text);
       }
